Class: Bio::RestrictionEnzyme::Fragments
- Inherits:
-
Array
- Object
- Array
- Bio::RestrictionEnzyme::Fragments
- Defined in:
- lib/bio/util/restriction_enzyme.rb
Overview
Bio::RestrictionEnzyme::Fragments inherits from Array.
Bio::RestrictionEnzyme::Fragments is a container for Fragment objects. It adds the
methods primary and complement which returns an Array of all
respective strands from it's Fragment members in alphabetically sorted
order. Note that it will
not return duplicate items and does not return the spacing/padding
that you would
find by accessing the members directly.
Example:
primary = ['attaca', 'g']
complement = ['atga', 'cta']
Note: unrelated to Bio::RestrictionEnzyme::Range::SequenceRange::Fragments
Instance Method Summary collapse
Instance Method Details
#complement ⇒ Object
209 |
# File 'lib/bio/util/restriction_enzyme.rb', line 209 def complement; strip_and_sort(:complement); end |
#primary ⇒ Object
208 |
# File 'lib/bio/util/restriction_enzyme.rb', line 208 def primary; strip_and_sort(:primary); end |